==> haskell-pandoc_3.1.11.1.orig.tar.gz: pandoc-3.1.11.1/test/command/pandoc-citeproc-401.md <==
```
% pandoc --citeproc -t markdown-citations
---
references:
- id: haslanger2012SocialConstructionDebunking
  type: chapter
  author:
  - family: Haslanger
    given: Sally
  issued:
  - year: 2012
  original-date:
  - year: 2003
  title: 'Social Construction: The ‘Debunking’ Project'
  title-short: Social Construction
  container-title: 'Resisting Reality: Social Construction and Social Critique'
  publisher: Oxford University Press
  publisher-place: Oxford
  event-place: Oxford
  page: 113–138
  ISBN: 978-0-19-989262-4

- id: haslanger2012FeminismMetaphysicsNegotiating
  type: chapter
  author:
  - family: Haslanger
    given: Sally
  issued:
  - year: 2012
  original-date:
  - year: 2000
  title: 'Feminism in Metaphysics: Negotiating the Natural'
  container-title: 'Resisting Reality: Social Construction and Social Critique'
  publisher: Oxford University Press
  publisher-place: Oxford
  event-place: Oxford
  page: 139–157
  ISBN: 978-0-19-989262-4
  language: en
...

Haslanger [-@haslanger2012SocialConstructionDebunking; @haslanger2012FeminismMetaphysicsNegotiating] says...
^D
Haslanger (\[2003\] 2012, \[2000\] 2012) says...

::: {#refs .references .csl-bib-body .hanging-indent entry-spacing="0"}
::: {#ref-haslanger2012FeminismMetaphysicsNegotiating .csl-entry}
Haslanger, Sally. (2000) 2012. "Feminism in Metaphysics: Negotiating the
Natural." In *Resisting Reality: Social Construction and Social
Critique*, 139--57. Oxford: Oxford University Press.
:::

::: {#ref-haslanger2012SocialConstructionDebunking .csl-entry}
---------. (2003) 2012. "Social Construction: The 'Debunking' Project."
In *Resisting Reality: Social Construction and Social Critique*,
113--38. Oxford: Oxford University Press.
:::
:::
```

==> haskell-pandoc_3.7.0.2.orig.tar.gz: pandoc-3.7.0.2/test/command/pandoc-citeproc-401.md <==
```
% pandoc --citeproc -t markdown-citations
---
references:
- id: haslanger2012SocialConstructionDebunking
  type: chapter
  author:
  - family: Haslanger
    given: Sally
  issued:
  - year: 2012
  original-date:
  - year: 2003
  title: 'Social Construction: The ‘Debunking’ Project'
  title-short: Social Construction
  container-title: 'Resisting Reality: Social Construction and Social Critique'
  publisher: Oxford University Press
  publisher-place: Oxford
  event-place: Oxford
  page: 113–138
  ISBN: 978-0-19-989262-4

- id: haslanger2012FeminismMetaphysicsNegotiating
  type: chapter
  author:
  - family: Haslanger
    given: Sally
  issued:
  - year: 2012
  original-date:
  - year: 2000
  title: 'Feminism in Metaphysics: Negotiating the Natural'
  container-title: 'Resisting Reality: Social Construction and Social Critique'
  publisher: Oxford University Press
  publisher-place: Oxford
  event-place: Oxford
  page: 139–157
  ISBN: 978-0-19-989262-4
  language: en
...

Haslanger [-@haslanger2012SocialConstructionDebunking; @haslanger2012FeminismMetaphysicsNegotiating] says...
^D
Haslanger (\[2003\] 2012, \[2000\] 2012) says...

::::: {#refs .references .csl-bib-body .hanging-indent entry-spacing="0"}
::: {#ref-haslanger2012FeminismMetaphysicsNegotiating .csl-entry}
Haslanger, Sally. (2000) 2012. "Feminism in Metaphysics: Negotiating the
Natural." In *Resisting Reality: Social Construction and Social
Critique*, 139--57. Oxford: Oxford University Press.
:::

::: {#ref-haslanger2012SocialConstructionDebunking .csl-entry}
---------. (2003) 2012. "Social Construction: The 'Debunking' Project."
In *Resisting Reality: Social Construction and Social Critique*,
113--38. Oxford: Oxford University Press.
:::
:::::
```
